@@ -1,3 +1,5 @@
+from datetime import datetime
+
 import pyodbc
 
 from mssql_to_python3_orm.base_db_info import BaseDbInfo
@@ -206,6 +208,24 @@ class Py2SQL:
         '''
         return f'[{self.get_table(table_name).table_schem}].[{table_name}]'
 
+    def get_table_primary_keys(self, table):
+        '''
+        :param table: table name
+        :return: primary key constraints of table
+        '''
+        if not self.cursor.tables(table=table).fetchone():
+            raise Exception(f'Table {table} does not exist in db {self.db_name()}')
+
+        self.cursor.execute('select * from INFORMATION_SCHEMA.KEY_COLUMN_USAGE where '
+                            f'TABLE_NAME = \'{table}\'')
+
+        primary_keys = []
+        for row in self.cursor:
+            if row.CONSTRAINT_NAME.startswith('PK_'):
+                primary_keys.append(row)
+
+        return primary_keys
+
     def get_slave_table_foreign_keys(self, table):
         '''
         :param table: table name
@@ -397,7 +417,8 @@ class Py2SQL:
             for index in range(len(row)):
                 res[index].append(row[index])
 
-        print(res)
+        # for debug only
+        # print(res)
 
         return res
 
@@ -447,4 +468,76 @@ class Py2SQL:
                 temp.append([names_and_types[item][0], names_and_types[item][1], row[item]])
             res.append(temp)
 
+        # for debug only
+        # print(res)
+
         return res
+
+    def create_object(self, table, id):
+        if not self.cursor.tables(table=table).fetchone():
+            raise Exception(f'Table {table} does not exist in db {self.db_name()}')
+
+        pk_column_name = ''
+
+        for row in self.get_slave_table_primary_keys(table):
+            pk_column_name = row[-2]
+
+        select_query = f'select * from {self.__get_table_object_name__(table)} where {pk_column_name}={id}'
+
+        # for debug only
+        # print(select_query)
+
+        self.create_class(table, table)
+        imp = __import__(table, fromlist=[table])
+        new_class = getattr(imp, table)
+
+        self.cursor.execute(select_query)
+        args = []
+
+        for row in self.cursor:
+            for arg in row:
+                args.append(arg)
+
+        if not len(args) == 0:
+            return new_class(*args)
+
+    def create_objects(self, table, fid, lid):
+        if not self.cursor.tables(table=table).fetchone():
+            raise Exception(f'Table {table} does not exist in db {self.db_name()}')
+
+        if not isinstance(fid, int):
+            raise Exception(f'fid must be int')
+
+        if not isinstance(lid, int):
+            raise Exception(f'lid must be int')
+
+        if not fid < lid:
+            raise Exception(f'fid must be less then lid')
+
+        pk_column_name = ''
+
+        for row in self.get_slave_table_primary_keys(table):
+            pk_column_name = row[-2]
+
+        select_query = f'with num_row as ( select row_number() over (order by {pk_column_name}) as nom, * from {self.__get_table_object_name__(table)}) select * from num_row where nom between {fid} and {lid};'
+
+        # for debug only
+        # print(select_query)
+
+        self.create_class(table, table)
+        imp = __import__(table, fromlist=[table])
+        new_class = getattr(imp, table)
+
+        self.cursor.execute(select_query)
+        res = []
+
+        for row in self.cursor:
+            args = []
+            for index in range(len(row)):
+                if not index == 0:
+                    args.append(row[index])
+            if not len(args) == 0:
+                res.append(new_class(*args))
+
+        return res
+
